@@ -5,4 +5,4 @@ from .customer import Customer
 class CustomerSavedSearch(ShopifyResource):
 
     def customers(cls, **kwargs):
-        return Customer._build_list(cls.get("customers", **kwargs))
+        return Customer._build_collection(cls.get("customers", **kwargs))
